Error

Enum Error 

pub enum Error<B> {
    Bus(B),
    Boot,
    SwReset,
    FifoSampGraterThanBuff,
}
Driver errors.

Variants



Bus(B)

An error occurred at the bus level. Any methods that access the I2C/SPI bus to interact with the sensor may return this error if the bus operation fails.

The generic type B represents the specific error generated by the HAL of the microcontroller in use.



Boot

An error occured during boot procedure



SwReset

An error occured during software reset procedure



FifoSampGraterThanBuff

The error return when the fifo sample size is grater than the buffer size